aboutsummaryrefslogtreecommitdiffstats
path: root/al
diff options
context:
space:
mode:
authorChris Robinson <[email protected]>2020-05-25 02:02:50 -0700
committerChris Robinson <[email protected]>2020-05-25 02:02:50 -0700
commit4d9d406966d541e1168771d7bc26e97ee428ca06 (patch)
treebe100c122fcdc6d508db07dd23dd83c46c65257c /al
parent070ed0d5ac7151aed8428d4a363c61a0bdfb5fa8 (diff)
Clarify an error message
Diffstat (limited to 'al')
-rw-r--r--al/source.cpp8
1 files changed, 5 insertions, 3 deletions
diff --git a/al/source.cpp b/al/source.cpp
index e26ecfec..a4c96deb 100644
--- a/al/source.cpp
+++ b/al/source.cpp
@@ -3319,17 +3319,19 @@ START_API_FUNC
else if(source->state == AL_INITIAL)
Current = BufferList;
if UNLIKELY(BufferList == Current)
- SETERR_RETURN(context, AL_INVALID_VALUE,, "Unqueueing pending buffers");
+ SETERR_RETURN(context, AL_INVALID_VALUE,, "Unqueueing %d buffer%s (none processed)", nb,
+ (nb==1) ? "" : "s");
ALuint i{1u};
while(i < static_cast<ALuint>(nb))
{
/* If the next bufferlist to check is NULL or is the current one, it's
* trying to unqueue pending buffers.
*/
ALbufferlistitem *next{BufferList->mNext.load(std::memory_order_relaxed)};
if UNLIKELY(!next || next == Current)
- SETERR_RETURN(context, AL_INVALID_VALUE,, "Unqueueing pending buffers");
+ SETERR_RETURN(context, AL_INVALID_VALUE,, "Unqueueing %d buffers (only %u processed)",
+ nb, i);
BufferList = next;
++i;
@@ -3319,17 +3319,19 @@ START_API_FUNC
{
/* If the next bufferlist to check is NULL or is the current one, it's
- * trying to unqueue pending buffers.
+ * trying to unqueue more buffers than are processed.
*/
ALbufferlistitem *next{BufferList->mNext.load(std::memory_order_relaxed)};